import "./root";
import * as _a from "../core/dom";
_a.styles.append(".bk-root .bk-tile-attribution a {\n  color: black;\n}\n");
export const bk_tile_attribution = "bk-tile-attribution";
//# sourceMappingURL=tiles.js.map