export const Align = ["start", "center", "end"];
export const Anchor = [
    "top_left", "top_center", "top_right",
    "center_left", "center", "center_right",
    "bottom_left", "bottom_center", "bottom_right",
];
export const AngleUnits = ["deg", "rad"];
export const BoxOrigin = ["corner", "center"];
export const ButtonType = ["default", "primary", "success", "warning", "danger"];
export const CalendarPosition = ["auto", "above", "below"];
export const Dimension = ["width", "height"];
export const Dimensions = ["width", "height", "both"];
export const Direction = ["clock", "anticlock"];
export const Distribution = ["uniform", "normal"];
export const FontStyle = ["normal", "italic", "bold", "bold italic"];
export const HatchPatternType = [
    'blank', 'dot', 'ring', 'horizontal_line', 'vertical_line', 'cross', 'horizontal_dash',
    'vertical_dash', 'spiral', 'right_diagonal_line', 'left_diagonal_line', 'diagonal_cross',
    'right_diagonal_dash', 'left_diagonal_dash', 'horizontal_wave', 'vertical_wave', 'criss_cross',
    ' ', '.', 'o', '-', '|', '+', '"', ':', '@', '/', '\\', 'x', ',', '`', 'v', '>', '*',
];
export const HTTPMethod = ["POST", "GET"];
export const HexTileOrientation = ["pointytop", "flattop"];
export const HoverMode = ["mouse", "hline", "vline"];
export const LatLon = ["lat", "lon"];
export const LegendClickPolicy = ["none", "hide", "mute"];
export const LegendLocation = Anchor;
export const LineCap = ["butt", "round", "square"];
export const LineJoin = ["miter", "round", "bevel"];
export const LinePolicy = ["prev", "next", "nearest", "interp", "none"];
export const Location = ["above", "below", "left", "right"];
export const Logo = ["normal", "grey"];
export const MarkerType = [
    "asterisk", "circle", "circle_cross", "circle_x", "cross",
    "dash", "diamond", "diamond_cross", "hex", "inverted_triangle",
    "square", "square_cross", "square_x", "triangle", "x",
];
export const Orientation = ["vertical", "horizontal"];
export const OutputBackend = ["canvas", "svg", "webgl"];
export const PaddingUnits = ["percent", "absolute"];
export const Place = ["above", "below", "left", "right", "center"];
export const PointPolicy = ["snap_to_data", "follow_mouse", "none"];
export const RadiusDimension = ["x", "y", "max", "min"];
export const RenderLevel = ["image", "underlay", "glyph", "annotation", "overlay"];
export const RenderMode = ["canvas", "css"];
export const ResetPolicy = ["standard", "event_only"];
export const RoundingFunction = ["round", "nearest", "floor", "rounddown", "ceil", "roundup"];
export const Side = ["above", "below", "left", "right"];
export const SizingMode = ["stretch_width", "stretch_height", "stretch_both", "scale_width", "scale_height", "scale_both", "fixed"];
export const Sort = ["ascending", "descending"];
export const SpatialUnits = ["screen", "data"];
export const StartEnd = ["start", "end"];
export const StepMode = ["after", "before", "center"];
export const TapBehavior = ["select", "inspect"];
export const TextAlign = ["left", "right", "center"];
export const TextBaseline = ["top", "middle", "bottom", "alphabetic", "hanging", "ideographic"];
export const TextureRepetition = ["repeat", "repeat_x", "repeat_y", "no_repeat"];
export const TickLabelOrientation = ["vertical", "horizontal", "parallel", "normal"];
export const TooltipAttachment = ["horizontal", "vertical", "left", "right", "above", "below"];
export const UpdateMode = ["replace", "append"];
export const VerticalAlign = ["top", "middle", "bottom"];
//# sourceMappingURL=enums.js.map